ApiKeyCredentials class

API key authentication using the x-chroma-token header.

This is the standard authentication method for ChromaDB Cloud and secured self-hosted instances.

Inheritance

Constructors

ApiKeyCredentials({required String apiKey})
Creates API key credentials.
const

Properties

apiKey String
The API key to use for authentication.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited