AuthProvider class abstract interface

Provides authentication credentials for ChromaDB API requests.

Implement this interface to supply custom authentication logic.

Example:

class ApiKeyProvider implements AuthProvider {
  final String apiKey;
  const ApiKeyProvider(this.apiKey);

  @override
  Future<AuthCredentials> getCredentials() async =>
      ApiKeyCredentials(apiKey: apiKey);
}
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCredentials() Future<AuthCredentials>
Returns the authentication credentials to use for API requests.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited