AuthenticationException class

Exception thrown when authentication fails.

This occurs when the API returns a 401 or 403 status code.

Inheritance

Constructors

AuthenticationException({required String message, StackTrace? stackTrace, Exception? cause, RequestMetadata? request, ResponseMetadata? response})
Creates an authentication exception.

Properties

cause Exception?
The underlying cause of this exception, if any.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable description of the error.
finalinherited
request RequestMetadata?
Metadata about the request that caused the error.
finalinherited
response ResponseMetadata?
Metadata about the error response.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace at the point where the exception was thrown.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited