CreateCollectionRequest class

Request to create a new collection.

Annotations
  • @immutable

Constructors

CreateCollectionRequest({required String name, Map<String, dynamic>? metadata, bool? getOrCreate})
Creates a create collection request.
const

Properties

getOrCreate bool?
If true, get an existing collection with this name instead of throwing an error if it already exists.
final
hashCode int
The hash code for this object.
no setteroverride
metadata Map<String, dynamic>?
Optional metadata for the collection.
final
name String
The name for the new collection.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, Object? metadata = unsetCopyWithValue, Object? getOrCreate = unsetCopyWithValue}) CreateCollectionRequest
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this request to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override