DetachFunctionResponse class

Response from detaching a function from a collection.

Annotations
  • @immutable

Constructors

DetachFunctionResponse({required bool success})
Creates a detach function response.
const
DetachFunctionResponse.fromJson(Map<String, dynamic> json)
Creates a response from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
Whether the detach operation was successful.
final

Methods

copyWith({bool? success}) DetachFunctionResponse
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this response to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override