Embeddable class sealed

Input for embedding generation.

This is a sealed class with two variants:

Implementers

Constructors

Embeddable.document(String text)
Creates an embeddable from a text document.
factory
Embeddable.image(String base64)
Creates an embeddable from a base64-encoded image.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited