copyWith method
Creates a copy of this response with optional modifications.
Implementation
VersionResponse copyWith({String? version}) {
return VersionResponse(version: version ?? this.version);
}
Creates a copy of this response with optional modifications.
VersionResponse copyWith({String? version}) {
return VersionResponse(version: version ?? this.version);
}