AbortedException class
Exception thrown when a request is aborted.
This occurs when the user cancels a request or the client is closed.
- Inheritance
-
- Object
- ChromaException
- AbortedException
Constructors
- AbortedException({required String message, StackTrace? stackTrace, Exception? cause})
- Creates an aborted exception.
Properties
- cause → Exception?
-
The underlying cause of this exception, if any.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable description of the error.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace at the point where the exception was thrown.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited