CollectionSchema class
Schema representation for collection index configurations.
This represents the server-side schema structure used for index management.
- Annotations
-
- @immutable
Constructors
Properties
-
cmek
→ Map<
String, dynamic> ? -
Customer-managed encryption key for collection data.
final
-
defaults
→ Map<
String, dynamic> -
Default index configurations for each value type.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
keys
→ Map<
String, dynamic> -
Key-specific index overrides.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceAttachedFunctionId → String?
-
ID of the attached function that created this output collection.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this schema to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override