DetachFunctionRequest class
Request to detach a function from a collection.
- Annotations
-
- @immutable
Constructors
- DetachFunctionRequest({bool? deleteOutput})
-
Creates a detach function request.
const
Properties
- deleteOutput → bool?
-
Whether to delete the output collection when detaching.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? deleteOutput = unsetCopyWithValue}) → DetachFunctionRequest - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this request to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override