GetAttachedFunctionResponse class
Response from getting an attached function.
- Annotations
-
- @immutable
Constructors
- GetAttachedFunctionResponse({required AttachedFunction attachedFunction})
-
Creates a get attached function response.
const
-
GetAttachedFunctionResponse.fromJson(Map<
String, dynamic> json) -
Creates a response from JSON.
factory
Properties
- attachedFunction → AttachedFunction
-
The attached function details.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{AttachedFunction? attachedFunction}) → GetAttachedFunctionResponse - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this response to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override