ResponseMetadata class
Metadata about an HTTP response.
This is included in exceptions to help with debugging.
Constructors
Properties
- bodyExcerpt → String
-
An excerpt of the response body (first 200 chars).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
The response headers.
final
- latency → Duration
-
The time taken to receive the response.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
The HTTP status code.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited