SearchPayload class
A single search query within a search request.
Defines the criteria for one search operation, including filtering, grouping, pagination, ranking, and field selection.
- Annotations
-
- @immutable
Constructors
-
SearchPayload({SearchFilter? filter, SearchGroupBy? groupBy, SearchLimit? limit, Map<
String, dynamic> ? rank, SearchSelect? select}) -
Creates a search payload.
const
-
SearchPayload.fromJson(Map<
String, dynamic> json) -
Creates a search payload from JSON.
factory
Properties
- filter → SearchFilter?
-
Filter criteria for the search.
final
- groupBy → SearchGroupBy?
-
Grouping criteria for results.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → SearchLimit?
-
Pagination limits.
final
-
rank
→ Map<
String, dynamic> ? -
Ranking configuration.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- select → SearchSelect?
-
Field selection for results.
final
Methods
-
copyWith(
{Object? filter = unsetCopyWithValue, Object? groupBy = unsetCopyWithValue, Object? limit = unsetCopyWithValue, Object? rank = unsetCopyWithValue, Object? select = unsetCopyWithValue}) → SearchPayload - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this payload to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override