Tenant class
A ChromaDB tenant.
Tenants provide multi-tenancy isolation in ChromaDB. Each tenant contains its own set of databases and collections.
- Annotations
-
- @immutable
Constructors
- Tenant({required String name})
-
Creates a tenant.
const
-
Tenant.fromJson(Map<
String, dynamic> json) -
Creates a tenant from JSON.
factory
Properties
Methods
-
copyWith(
{String? name}) → Tenant - Creates a copy of this tenant with optional modifications.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this tenant to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override