VersionResponse class
Response from the version endpoint.
Contains version information about the ChromaDB server.
- Annotations
-
- @immutable
Constructors
- VersionResponse({required String version})
-
Creates a version response.
const
-
VersionResponse.fromJson(Map<
String, dynamic> json) -
Creates a version response from JSON.
factory
Properties
Methods
-
copyWith(
{String? version}) → VersionResponse - Creates a copy of this response with optional modifications.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this response to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override